Advanced Functions
::::::::::::::::::

.. toctree::
   :caption: Advanced Functions
   :maxdepth: 2

   OptionalParameters.rst
   KeywordParameters.rst
   Anonymousfunctionswithlambdaexpressions.rst
   ProgrammingWithStyle.rst
   MethodInvocations.rst
   FunctionWrappingAndDecorators.rst
   Exercises.rst
   ChapterAssessment.rst
